/* 
 * Tcl_ResultCodeException.java --
 *
 *	This file defines the class Tcl_ResultCodeException, an abstract
 *      class which serves as the supertype for all exceptions representing
 *      Tcl return code conditions, including errors, control-flow conditions
 *      such as break, continue, and return, and user-defined exceptions.
 *
 * Copyright (c) 1996 by Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * SCCS:
 */

package tcl;

/**
 * An abstract base class for Tcl result-code exceptions.
 *
 * @version     1.0, 23 August 1996
 * @author      Glenn Vanderburg
 */

public abstract
class Tcl_ResultCodeException extends Exception {

    /**
     * Creates a new exception.
     * @param detail a string describing the condition which
     * caused the exception.
     */
    protected
    Tcl_ResultCodeException(String detail)
    {
	super(detail);
    }

    /**
     * Returns the Tcl result code for this exception
     * @return the Tcl result code
     */
    public abstract int getCode();
}
