/* 
 * Tcl_ReturnException.java --
 *
 *	This file defines the class Tcl_ReturnException, which is used
 *      to signal Tcl return conditions within Java code (under some
 *      circumstances).
 *
 * Copyright (c) 1996 by Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * SCCS:
 */

package tcl;

/**
 * A Tcl result-code exception indicating a "return" condition.
 *
 * @version     1.0, 23 August 1996
 * @author      Glenn Vanderburg
 */

public
class Tcl_ReturnException extends Tcl_ControlException 
{
    /**
     * The result of the Tcl command
     */
    private Value result;
    
    /**
     * Creates a new exception.
     * @param result the result of the Tcl command
     */
    public
    Tcl_ReturnException(Value result)
    {
	super("A \"return\" request from a Tcl script has occurred");
	this.result = result;
    }

    /**
     * Creates a new exception.
     * @param result the result of the Tcl command
     */
    public
    Tcl_ReturnException(String result)
    {
	this(new Value(result));
    }

    /**
     * Returns the result value associated with this condition
     * @return the result value
     */
    public final Value
    getResult()
    {
	return result;
    }

    /**
     * Returns the Tcl result code for this exception
     * @return the Tcl result code
     */
    public final int
    getCode()
    {
	return Interp.TCL_RETURN;
    }
}
