# A simple TCL application to demonstrate a use of the tcljava interface.
#
# Copyright (c) 1992-1994 The Regents of the University of California.
# Copyright (c) 1994-1995 Sun Microsystems, Inc.
#
# See the file "license.terms" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

######################################## Globals
# A buffer for the contents info.
set zipcontents {}
# Column widths
set columnsizes {13 13 7 30}
# A place to put the new application.
set mybase ".zip_demo"
if {[winfo exists $mybase]} {
    destroy $mybase
}
toplevel $mybase

# Setup the interface,
label $mybase.label1 -anchor w -justify left -text {Zip View}
catch {$mybase.label1 config -font {-*-Helvetica-Bold-R-Normal--*-140-*-*-*-*-*-*}}
pack $mybase.label1 -side top -fill x
label $mybase.label2 -anchor w -justify left -text "\
Enter the pathname of the zip file in the entry below, \n\
and press the scan button.\
"
catch {$mybase.label2 config -font {-*-Helvetica-Medium-R-Normal--*-120-*-*-*-*-*-*}}
pack $mybase.label2 -side top -anchor w
frame $mybase.b
button $mybase.b.quitButton -command "destroy $mybase" -padx 11 -pady 4 -text Quit
pack $mybase.b.quitButton -side left
button $mybase.b.scanButton -command "doScan" -padx 11 -pady 4 -text Scan
pack $mybase.b.scanButton -side left
entry $mybase.b.entry
pack $mybase.b.entry -side left -fill x -expand 1
#pack [button $mybase.b.checkout -command {puts "Here";exec mkdir /tmp/junk;puts "Done."}] -side left
pack $mybase.b -side top -fill x
frame $mybase.lb
listbox $mybase.lb.listbox -height 0 -width 0 -yscrollc "$mybase.lb.sb set"
catch {$mybase.lb.listbox config -font -*-Courier-Medium-R-Normal--*-120-*-*-*-*-*-*}
scrollbar $mybase.lb.sb -command "$mybase.lb.listbox yview" -orient v
pack $mybase.lb.sb -side right -fill y
pack $mybase.lb.listbox -fill both -expand 1
pack $mybase.lb -side top -fill both -expand 1

# Bind the appropariate keys to the two buttons
bind $mybase.b.quitButton <Key-Q> {destroy $mybase}
bind $mybase.b.scanButton <Key-S> {doScan}
bind $mybase.b.quitButton <Key-q> {destroy $mybase}
bind $mybase.b.scanButton <Key-s> {doScan}
bind all <Escape> {destroy $mybase}

# Set up the default action on an entry.
bind $mybase.b.entry <Return> {doScan}

# Set the font on the listbox, just to be sure.
$mybase.lb.listbox config -font {-adobe-courier-medium-r-*-*-12-*-*-*-*-*-*-*}

# Make sure the java command has been loaded.
if {[info comm zipfilelist] == {}} {
    puts "The command 'zipfilelist' doesn't exist. Did you start this"
    puts "script from within Java?"
    destroy [winfo toplevel $mybase]
    return 
}

# Scan the zip file, and put the names of the entries in the 
# listbox.
proc doScan {} {
    global zipcontents mybase
    set zipcontents [zipfilelist [$mybase.b.entry get]]
    fillBox
}

# A crude columnizer.  Depends on the font being monospaced, and on tk4.1b2.
proc columnize {args} {
    global columnsizes
    set result {}
    set idx 0
    set wl [llength $columnsizes]
    set al [llength $args]
    while {$idx < $wl && $idx < $al} {
	set width [lindex $columnsizes $idx]
	set txt [lindex $args $idx]
        set result "${result} ${txt}[string range {                            } 0 [expr $width-[string length $txt]]]"
	incr idx
    }
    return $result
}

# Puts the elements from the global zipcontents into the list box.
proc fillBox {} {
    global mybase zipcontents
    $mybase.lb.listbox delete 0 end
    foreach i $zipcontents {
	$mybase.lb.listbox insert end [columnize \
                                       [lindex $i 0] \
                                       [lindex $i 1] \
                                       [lindex $i 2] \
                                       [lindex $i 3]]
    }
}
